"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.generateColorUtilities = void 0;
const generateColorUtilities = ({ theme, addUtilities }) => {
    const primaryColors = theme('colors.primary', {});
    const secondaryColors = theme('colors.secondary', {});
    const tertiaryColors = theme('colors.tertiary', {});
    const createUtilities = (colors, prefix) => {
        const utilities = {};
        Object.entries(colors).forEach(([key, value]) => {
            utilities[`.${prefix}-${key}`] = { backgroundColor: value };
            utilities[`.text-${prefix}-${key}`] = { color: value };
            utilities[`.border-${prefix}-${key}`] = { borderColor: value };
        });
        return utilities;
    };
    const primaryUtilities = createUtilities(primaryColors, 'primary');
    const secondaryUtilities = createUtilities(secondaryColors, 'secondary');
    const tertiaryUtilities = tertiaryColors ? createUtilities(tertiaryColors, 'tertiary') : {};
    addUtilities({
        ...primaryUtilities,
        ...secondaryUtilities,
        ...tertiaryUtilities,
    });
};
exports.generateColorUtilities = generateColorUtilities;
